@@ -2,7 +2,8 @@
 #    @Author-Email: justincpresley@gmail.com
 #    @Project: NDN State Vector Sync Protocol
 #    @Source-Code: https://github.com/justincpresley/ndn-python-svs
-#    @Pip-Library: https://pypi.org/project/ndn-svs/
+#    @Pip-Library: https://pypi.org/project/ndn-svs
+#    @Documentation: https://ndn-python-svs.readthedocs.io
 
 # Basic Libraries
 from typing import Optional, Callable
@@ -10,7 +11,7 @@ from typing import Optional, Callable
 from ndn.encoding import Name
 from ndn.security import Keychain
 from ndn.transport.stream_socket import Face
-from ndn_python_repo import Storage
+from ndn.storage import Storage
 # Custom Imports
 from .security import SecurityOptions
 from .svs import SVSync
